#
# spec file
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2016, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%define skip_python2 1
# Scrapy on TW has disabled python36 due to uvloop
%define skip_python36 1
Name:           python-itemadapter%{psuffix}
Version:        0.8.0
Release:        1.1
Summary:        Wrapper for data container objects
License:        BSD-3-Clause
URL:            https://github.com/scrapy/itemadapter
Source:         https://github.com/scrapy/itemadapter/archive/v%{version}.tar.gz#/itemadapter-%{version}.tar.gz
BuildRequires:  %{python_module setuptools >= 40.5.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module Scrapy >= 2.0}
BuildRequires:  %{python_module attrs}
BuildRequires:  %{python_module pydantic}
BuildRequires:  %{python_module pytest >= 5.4}
%endif
%python_subpackages

%description
The ItemAdapter class is a wrapper for data container objects, providing
a common interface to handle objects of different types in an uniform
manner, regardless of their underlying implementation.

%prep
%setup -q -n itemadapter-%{version}

%build
%python_build

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%pytest
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/itemadapter
%{python_sitelib}/itemadapter-%{version}-py*.egg-info
%endif

%changelog
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 0.8.0:
  * Dropped Python 3.6 support, and made Python 3.11 support
    official
  * It is now possible to declare custom `ItemAdapter` subclasses
    with their own `ADAPTER_CLASSES` attribute, allowing to
    support different item types in different parts of the same
    code base
  * Improved type hint support
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.7.0 (2022-08-02)
  ItemAdapter.get_field_names_from_class (#64)
- Update to 0.6.0 (2022-05-12)
  Slight performance improvement (#62)
- Update to 0.5.0 (2022-03-18)
  Improve performance by removing imports inside functions (#60)
* Sat Oct 30 2021 Ben Greiner <code@bnavigator.de>
- Update to v0.4.0
  * Added ItemAdapter.is_item_class and
    ItemAdapter.get_field_meta_from_class (#54)
  * Added built-in support for pydantic models (#53)
  * Adapter interface: added the ability to support arbitrary
    types, by implementing a MutableMapping-based interface. By way
    of this change, now any type can be used as a Scrapy item.
  * Dropped support for Python 3.5 (#38).
  * The new get_field_meta_from_class function offers the same
    functionality as ItemAdapter.get_field_meta but for an item
    class, as opposed to an item object (#34, #35).
  * ItemAdapter.__repr__ no longer raises exceptions caused by the
    underlying item (#31, #41).
- Disable python36 build due to Scrapy
* Wed Jul  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Switch to multibuild
- Fix the sitelib/sitearch and all the dependencies
* Tue Jul  7 2020 Jacob W <jacob@jacobwinski.com>
- Update spec file:
  * Change to github archive, which includes tests.
  * Enable tests.
  * Add BuildRequires that is required for tests to pass.
* Thu Jul  2 2020 Jacob W <jacob@jacobwinski.com>
- Initial package of python-itemadapter version 0.1.0
